Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: compiler/javatests/com/google/dart/compiler/type/TypeAnalyzerCompilerTest.java

Issue 10825346: Fix bugs in parser and update tests to use new directive syntax (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « compiler/javatests/com/google/dart/compiler/parser/SyntaxTest.java ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: compiler/javatests/com/google/dart/compiler/type/TypeAnalyzerCompilerTest.java
===================================================================
--- compiler/javatests/com/google/dart/compiler/type/TypeAnalyzerCompilerTest.java (revision 10652)
+++ compiler/javatests/com/google/dart/compiler/type/TypeAnalyzerCompilerTest.java (working copy)
@@ -1312,31 +1312,31 @@
}
/**
- * If there was <code>#import</code> with invalid {@link URI}, it should be reported as error, not
+ * If there was <code>import</code> with invalid {@link URI}, it should be reported as error, not
* as an exception.
*/
public void test_invalidImportUri() throws Exception {
List<DartCompilationError> errors =
analyzeLibrarySourceErrors(makeCode(
"// filler filler filler filler filler filler filler filler filler filler",
- "#library('test');",
- "#import('badURI');",
+ "library test;",
+ "import 'badURI';",
""));
- assertErrors(errors, errEx(DartCompilerErrorCode.MISSING_SOURCE, 3, 1, 18));
+ assertErrors(errors, errEx(DartCompilerErrorCode.MISSING_SOURCE, 3, 1, 16));
}
/**
* If there was <code>#source</code> with invalid {@link URI}, it should be reported as error, not
* as an exception.
*/
public void test_invalidSourceUri() throws Exception {
List<DartCompilationError> errors =
analyzeLibrarySourceErrors(makeCode(
"// filler filler filler filler filler filler filler filler filler filler",
- "#library('test');",
- "#source('badURI');",
+ "library test;",
+ "part 'badURI';",
""));
- assertErrors(errors, errEx(DartCompilerErrorCode.MISSING_SOURCE, 3, 1, 18));
+ assertErrors(errors, errEx(DartCompilerErrorCode.MISSING_SOURCE, 3, 1, 14));
}
/**
« no previous file with comments | « compiler/javatests/com/google/dart/compiler/parser/SyntaxTest.java ('k') | no next file » | no next file with comments »
@@ -1312,31 +1312,31 @@
}
/**
- * If there was <code>#source</code> with invalid {@link URI}, it should be reported as error, not
+ * If there was <code>part</code> with invalid {@link URI}, it should be reported as error, not
* as an exception.
*/

Powered by Google App Engine
This is Rietveld 408576698